==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-cpuload/translations/cpuload_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LxQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Vytížení procesoru %1%</translation>
    </message>
    <message>
        <location filename="../lxqtcpuload.cpp" line="119"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxQtCpuLoadConfiguration</name>
    <message>
        <source>LxQt Cpu Load settings</source>
        <translation type="vanished">Nastavení vytížení procesoru v LxQtu</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Ukázat text</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Obnovovací interval:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Směr pruhu</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Zdola nahoru</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Shora dolů</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Zleva doprava</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Zprava doleva</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-cpuload/translations/cpuload_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>Vytížení procesoru %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Nastavení zobrazování vytížení procesoru</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Zobrazovat text</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Interval obnovování:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Směr pruhu:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Šířka pruhu:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Zdola nahoru</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Shora dolů</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Zleva doprava</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Zprava doleva</translation>
    </message>
</context>
</TS>
